## ----setup, include=FALSE-----------------------------------------------------
# Global options
library(knitr)
# opts_chunk$set(fig.path="fig/")

## ----install, eval=FALSE------------------------------------------------------
#  install.packages("eurostat")

## ----install2, eval=FALSE-----------------------------------------------------
#  library(devtools)
#  install_github("ropengov/eurostat")

## ---- echo=FALSE--------------------------------------------------------------
library(eurostat)

